Package: highr
Type: Package
Title: Syntax Highlighting for R Source Code
Version: 0.9
Authors@R: c(
    person("Yihui", "Xie", role = c("aut", "cre"), email = "xie@yihui.name", comment = c(ORCID = "0000-0003-0645-5666")),
    person("Yixuan", "Qiu", role = "aut"),
    person("Christopher", "Gandrud", role = "ctb"),
    person("Qiang", "Li", role = "ctb")
    )
Description: Provides syntax highlighting for R source code. Currently it
    supports LaTeX and HTML output. Source code of other languages is supported
    via Andre Simon's highlight package (<http://www.andre-simon.de>).
Depends: R (>= 3.2.3)
Imports: xfun (>= 0.18)
Suggests: knitr, markdown, testit
License: GPL
URL: https://github.com/yihui/highr
BugReports: https://github.com/yihui/highr/issues
VignetteBuilder: knitr
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2021-04-16 21:12:10 UTC; yihui
Author: Yihui Xie [aut, cre] (<https://orcid.org/0000-0003-0645-5666>),
  Yixuan Qiu [aut],
  Christopher Gandrud [ctb],
  Qiang Li [ctb]
Maintainer: Yihui Xie <xie@yihui.name>
Repository: CRAN
Date/Publication: 2021-04-16 21:50:05 UTC
