# Generated by roxygen2: do not edit by hand

export(hi_andre)
export(hi_html)
export(hi_latex)
export(hilight)
import(utils)
importFrom(xfun,raw_string)
importFrom(xfun,split_source)
importFrom(xfun,valid_syntax)
